function tform = blockShiftTform(image_size)

% From MATLAB Techniques for Image Processing by Steve Eddins
% Copyright 2012-2014 The MathWorks, Inc.

M = image_size(1);
N = image_size(2);

block_sizes = 8:4:32;

max_shift = 32;

yshift = zeros(N,1);
xshift = zeros(M,1);

dx = 0;
for x = 1:N
    if dx == 0
        % Choose a new shift and a block size.
        r = round(2*max_shift*(rand - 0.5));
        P = numel(block_sizes);
        block_size_index = floor(P*rand) + 1;
        dx = block_sizes(block_size_index);
    else
        % Still in same block. Decrement block counter.
        dx = dx - 1;
    end
    yshift(x) = r;
end

dy = 0;
for y = 1:M
    if dy == 0
        % Choose a new shift and a block size.
        r = round(2*max_shift*(rand - 0.5));
        P = numel(block_sizes);
        block_size_index = floor(P*rand) + 1;
        dy = block_sizes(block_size_index);
    else
        % Still in same block. Decrement block counter.
        dy = dy - 1;
    end
    xshift(y) = r;
end

tdata.xshift = xshift;
tdata.yshift = yshift;
tdata.M = M;
tdata.N = N;
        
tform = maketform('custom',2,2,[],@T_inv,tdata);

function uv = T_inv(xy,tform)
x = xy(:,1);
y = xy(:,2);

x = round(x);
x = min(max(x,1),tform.tdata.N);

y = round(y);
y = min(max(y,1),tform.tdata.M);

u = x + tform.tdata.xshift(y);
v = y + tform.tdata.yshift(x);

uv = [u,v];
